@@ -1,22 +1,11 @@
-/* Copyright (C) 2019 Christian Krippendorf <Coding@Christian-Krippendorf.de>
- *
- * Kmahjongg is free software; you can redistribute it and/or modify it under 
- * the terms of the GNU General Public License as published by the Free 
- * Software Foundation; either version 2 of the License, or (at your option) 
- * any later version.
- *
- * This program is distributed in the hope that it will be useful, but WITHOUT 
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
- * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more 
- * details.
- *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51 
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */
+/*
+    SPDX-FileCopyrightText: 2019 Christian Krippendorf <Coding@Christian-Krippendorf.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // own
 #include "gameremovedtiles.h"
-#include "kmahjonggtileset.h"
 #include "gamedata.h"
 
 // Qt
@@ -24,8 +13,12 @@
 #include <QPainter>
 #include <QPixmap>
 
+// KF
 #include <KLocalizedString>
 
+// LibKMahjongg
+#include <KMahjonggTileset>
+
 
 GameRemovedTiles::GameRemovedTiles(QGraphicsObject * object)
     : QGraphicsObject(object)
@@ -218,3 +211,5 @@ void GameRemovedTiles::removeLastItem()
 {
     m_itemFaces->removeLast();
 }
+
+#include "moc_gameremovedtiles.cpp"
